@@ -6,9 +6,19 @@ use clap::{Parser, Subcommand};
 pub struct Args {
     #[command(subcommand)]
     pub command: Option<Commands>,
+
+    /// Send keys on startup (eg: `gitu -k ll`).
+    ///     It is possible to send:
+    ///     - single char-keys: a, b, c, ...
+    ///     - special keys: <backspace>, <enter>, <up>, <tab>, <delete>, <esc>, ...
+    ///     - modifiers: <ctrl+a>, <ctrl+shift+alt+a>, <shift+delete>
+    #[clap(short, long, verbatim_doc_comment)]
+    pub keys: Option<String>,
+
     /// Print one frame and exit. Useful for debugging.
     #[clap(long, action)]
     pub print: bool,
+
     /// Enable logging to 'gitu.log'
     #[clap(long, action)]
     pub log: bool,
