@@ -50,7 +50,7 @@ impl PendingMenu {
             is_hidden: false,
             args: match menu {
                 Menu::Root => vec![],
-                Menu::Branch => ops::checkout::init_args(),
+                Menu::Branch => ops::branch::init_args(),
                 Menu::Commit => ops::commit::init_args(),
                 Menu::Fetch => ops::fetch::init_args(),
                 Menu::Help => vec![],
