@@ -1,6 +1,12 @@
-use super::{create_prompt_with_default, selected_rev, OpTrait};
-use crate::{items::TargetData, menu::arg::Arg, state::State, term::Term, Action, Res};
-use std::process::Command;
+use super::{selected_rev, OpTrait};
+use crate::{
+    items::TargetData,
+    menu::arg::Arg,
+    state::{PromptParams, State},
+    term::Term,
+    Action, Res,
+};
+use std::{process::Command, rc::Rc};
 
 pub(crate) fn init_args() -> Vec<Arg> {
     vec![]
@@ -9,12 +15,19 @@ pub(crate) fn init_args() -> Vec<Arg> {
 pub(crate) struct ResetSoft;
 impl OpTrait for ResetSoft {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(create_prompt_with_default(
-            "Soft reset to",
-            reset_soft,
-            selected_rev,
-            true,
-        ))
+        Some(Rc::new(move |state: &mut State, term: &mut Term| {
+            let rev = state.prompt(
+                term,
+                &PromptParams {
+                    prompt: "Soft reset to",
+                    create_default_value: Box::new(selected_rev),
+                    ..Default::default()
+                },
+            )?;
+
+            reset_soft(state, term, &rev)?;
+            Ok(())
+        }))
     }
 
     fn display(&self, _state: &State) -> String {
@@ -35,12 +48,19 @@ fn reset_soft(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
 pub(crate) struct ResetMixed;
 impl OpTrait for ResetMixed {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(create_prompt_with_default(
-            "Mixed reset to",
-            reset_mixed,
-            selected_rev,
-            true,
-        ))
+        Some(Rc::new(move |state: &mut State, term: &mut Term| {
+            let rev = state.prompt(
+                term,
+                &PromptParams {
+                    prompt: "Mixed reset to",
+                    create_default_value: Box::new(selected_rev),
+                    ..Default::default()
+                },
+            )?;
+
+            reset_mixed(state, term, &rev)?;
+            Ok(())
+        }))
     }
 
     fn display(&self, _state: &State) -> String {
@@ -61,12 +81,19 @@ fn reset_mixed(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
 pub(crate) struct ResetHard;
 impl OpTrait for ResetHard {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(create_prompt_with_default(
-            "Hard reset to",
-            reset_hard,
-            selected_rev,
-            true,
-        ))
+        Some(Rc::new(move |state: &mut State, term: &mut Term| {
+            let rev = state.prompt(
+                term,
+                &PromptParams {
+                    prompt: "Hard reset to",
+                    create_default_value: Box::new(selected_rev),
+                    ..Default::default()
+                },
+            )?;
+
+            reset_hard(state, term, &rev)?;
+            Ok(())
+        }))
     }
 
     fn display(&self, _state: &State) -> String {
