@@ -1,14 +1,14 @@
 use super::Screen;
 use crate::{config::Config, items::log, Res};
 use git2::{Oid, Repository};
-use ratatui::prelude::Rect;
+use ratatui::layout::Size;
 use regex::Regex;
 use std::rc::Rc;
 
 pub(crate) fn create(
     config: Rc<Config>,
     repo: Rc<Repository>,
-    size: Rect,
+    size: Size,
     limit: usize,
     rev: Option<Oid>,
     msg_regex: Option<Regex>,
